==> nextcloud-18.0.6.tgz: nextcloud/apps/comments/l10n/sk.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentáre",
    "You commented" : "Komentovali ste",
    "%1$s commented" : "%1$s komentoval",
    "{author} commented" : "{author} komentoval",
    "You commented on %1$s" : "Komentovali ste %1$s",
    "You commented on {file}" : "Komentovali ste {file}",
    "%1$s commented on %2$s" : "%1$s komentoval %2$s",
    "{author} commented on {file}" : "{author} komentoval {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentáre</strong> pre súbory",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Boli ste spomenutý v \"{file}\", v komentári používateľom ktorý bol už vymazaný",
    "{user} mentioned you in a comment on “{file}”" : "{user} vás spomenul v komentári k “{file}”",
    "Files app plugin to add comments to files" : "Plugin súborovej aplikácie ktorý umožňuje pridávať komentáre k súborom",
    "Edit comment" : "Upraviť komentár",
    "Delete comment" : "Zmazať komentár",
    "New comment …" : "Nový komentár ...",
    "Post" : "Odoslať",
    "Cancel" : "Zrušiť",
    "[Deleted user]" : "[Zmazaný užívateľ]",
    "No comments yet, start the conversation!" : "Žiadne komentáre, začnite konverzáciu!",
    "More comments …" : "Ďalšie komentáre ...",
    "Save" : "Uložiť",
    "Allowed characters {count} of {max}" : "Počet povolených znakov {count} z {max}",
    "Error occurred while retrieving comment with ID {id}" : "Pri načítavaní komentára s id {id} nastala chyba",
    "Error occurred while updating comment with id {id}" : "Pri aktualizovaní komentára s id {id} nastala chyba",
    "Error occurred while posting comment" : "Pri odosielaní komentára nastala chyba",
    "_%n unread comment_::_%n unread comments_" : ["%n neprečítaný komentár","%n neprečítaných komentárov","%n neprečítaných komentárov","%n neprečítaných komentárov"],
    "_1 new comment_::_{unread} new comments_" : ["1 nový komentár","{unread} nové komentáre","{unread} nových komentárov","{unread} nových komentárov"],
    "Comment" : "Komentár"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-19.0.9.tgz: nextcloud/apps/comments/l10n/sk.js <==
OC.L10N.register(
    "comments",
    {
    "Comments" : "Komentáre",
    "You commented" : "Komentovali ste",
    "%1$s commented" : "%1$s komentoval",
    "{author} commented" : "{author} komentoval",
    "You commented on %1$s" : "Komentovali ste %1$s",
    "You commented on {file}" : "Komentovali ste {file}",
    "%1$s commented on %2$s" : "%1$s komentoval %2$s",
    "{author} commented on {file}" : "{author} komentoval {file}",
    "<strong>Comments</strong> for files" : "<strong>Komentáre</strong> pre súbory",
    "You were mentioned on “{file}”, in a comment by a user that has since been deleted" : "Boli ste spomenutý v \"{file}\", v komentári používateľom ktorý bol už vymazaný",
    "{user} mentioned you in a comment on “{file}”" : "{user} vás spomenul v komentári k “{file}”",
    "Files app plugin to add comments to files" : "Plugin súborovej aplikácie ktorý umožňuje pridávať komentáre k súborom",
    "Edit comment" : "Upraviť komentár",
    "Delete comment" : "Zmazať komentár",
    "No comments yet, start the conversation!" : "Žiadne komentáre, začnite konverzáciu!",
    "Retry" : "Skúsiť znova",
    "_%n unread comment_::_%n unread comments_" : ["%n neprečítaný komentár","%n neprečítaných komentárov","%n neprečítaných komentárov","%n neprečítaných komentárov"],
    "_1 new comment_::_{unread} new comments_" : ["1 nový komentár","{unread} nové komentáre","{unread} nových komentárov","{unread} nových komentárov"],
    "Comment" : "Komentár",
    "Comment deleted" : "Komentár bol odstránený",
    "New comment …" : "Nový komentár ...",
    "Post" : "Odoslať",
    "Cancel" : "Zrušiť",
    "[Deleted user]" : "[Zmazaný užívateľ]",
    "More comments …" : "Ďalšie komentáre ...",
    "Save" : "Uložiť",
    "Allowed characters {count} of {max}" : "Počet povolených znakov {count} z {max}",
    "Error occurred while retrieving comment with ID {id}" : "Pri načítavaní komentára s id {id} nastala chyba",
    "Error occurred while updating comment with id {id}" : "Pri aktualizovaní komentára s id {id} nastala chyba",
    "Error occurred while posting comment" : "Pri odosielaní komentára nastala chyba"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
